@@ -53,57 +53,82 @@ def test_model_saver():
             DataTypePreprocessor,
         ],
     )
-    print(json.dumps(data[0]))
+    print(json.dumps(data[0], indent=4, sort_keys=True))
     assert data[0]["model"] == {
-        "type": "object",
-        "record-ui-schema-class": "test.services.records.ui_schema.TestUISchema",  # NOSONAR
-        "record-dumper-extensions": [],
-        "schema-name": "test-1.0.0.json",
-        "flask-extension-name": "test",
-        "flask-commands-setup-cfg": "test",
-        "record-resource-config-class": "test.resources.records.config.TestResourceConfig",
-        "invenio-record-service-config-extra-code": "",
-        "package-base-upper": "TEST",
-        "invenio-record-extra-code": "",
-        "ext-class": "test.ext.TestExt",
-        "kebap-package": "test",
-        "record-records-package": "test.records",
-        "record-service-class": "test.services.records.service.TestService",
+        "cli-function": "test.cli.group",
         "collection-url": "/test/",
-        "invenio-record-facets-extra-code": "",
-        "invenio-record-permissions-extra-code": "",
+        "config-dummy-class": "test.config.DummyClass",
+        "config-package": "test.config",
+        "config-resource-class-key": "TEST_RESOURCE_CLASS_TEST",
+        "config-resource-config-key": "TEST_RESOURCE_CONFIG_TEST",
+        "config-resource-register-blueprint-key": "TEST_REGISTER_BLUEPRINT",
+        "config-service-class-key": "TEST_SERVICE_CLASS_TEST",
+        "config-service-config-key": "TEST_SERVICE_CONFIG_TEST",
         "create-blueprint-from-app": "test.views.create_blueprint_from_app_test",
+        "ext-class": "test.ext.TestExt",
+        "extension-suffix": "test",
+        "flask-commands-setup-cfg": "test",
+        "flask-extension-name": "test",
+        "generate-record-pid-field": True,
+        "index-name": "test-test-1.0.0",
+        "invenio-config-extra-code": "",
+        "invenio-ext-extra-code": "",
+        "invenio-proxies-extra-code": "",
+        "invenio-record-dumper-extra-code": "",
+        "invenio-record-extra-code": "",
+        "invenio-record-facets-extra-code": "",
+        "invenio-record-metadata-extra-code": "",
+        "invenio-record-object-schema-extra-code": "",
+        "invenio-record-permissions-extra-code": "",
+        "invenio-record-resource-config-extra-code": "",
+        "invenio-record-resource-extra-code": "",
         "invenio-record-schema-extra-code": "",
+        "invenio-record-search-options-extra-code": "",
+        "invenio-record-service-config-extra-code": "",
+        "invenio-record-service-extra-code": "",
+        "invenio-version-extra-code": "",
+        "invenio-views-extra-code": "",
+        "jsonschemas-package": "test.records.jsonschemas",
+        "kebap-package": "test",
+        "mapping-file": "test/records/mappings/os-v2/test/test-1.0.0.json",
+        "mapping-package": "test.records.mappings",
         "marshmallow": {
-            "schema-class": "test.services.records.schema.TestSchema",  # NOSONAR
-            "generate": True,
             "base-classes": ["ma.Schema"],
+            "generate": True,
+            "schema-class": "test.services.records.schema.TestSchema",
         },
-        "record-api-blueprints-setup-cfg": "test",
+        "model-name": "test",
+        "oarepo-models-setup-cfg": "test",
+        "package": "test",
+        "package-base": "test",
+        "package-base-upper": "TEST",
+        "package-path": "test",
+        "permissions": {"presets": []},
+        "profile-package": "records",
         "properties": {
             "a": {
                 "marshmallow": {
-                    "field-class": "ma_fields.String",  # NOSONAR
-                    "validators": [],
+                    "field-class": "ma_fields.String",
                     "imports": [],
+                    "validators": [],
                 },
                 "type": "keyword",
                 "ui": {},
             },
             "b": {
                 "marshmallow": {
-                    "generate": True,
                     "field-class": "ma_fields.Nested",
-                    "validators": [],
-                    "schema-class": "test.services.records.schema.BSchema",
+                    "generate": True,
                     "imports": [],
+                    "schema-class": "test.services.records.schema.BSchema",
+                    "validators": [],
                 },
                 "properties": {
                     "c": {
                         "marshmallow": {
                             "field-class": "ma_fields.String",
-                            "validators": [],
                             "imports": [],
+                            "validators": [],
                         },
                         "type": "keyword",
                     }
@@ -112,88 +137,71 @@ def test_model_saver():
             },
             "metadata": {
                 "marshmallow": {
-                    "schema-class": "test.services.records.schema.TestMetadataSchema",  # NOSONAR
-                    "generate": True,
                     "base-classes": ["ma.Schema"],
                     "field-class": "ma_fields.Nested",
-                    "validators": [],
+                    "generate": True,
                     "imports": [],
+                    "schema-class": "test.services.records.schema.TestMetadataSchema",
+                    "validators": [],
                 },
                 "properties": {},
                 "type": "object",
+                "ui": {
+                    "marshmallow": {
+                        "base-classes": ["BaseObjectSchema"],
+                        "generate": True,
+                        "schema-class": "test.services.records.ui_schema.TestMetadataUISchema",
+                    }
+                },
             },
         },
-        "config-resource-register-blueprint-key": "TEST_REGISTER_BLUEPRINT",
-        "invenio-ext-extra-code": "",
-        "record-prefix": "Test",
-        "record-search-options-class": "test.services.records.search.TestSearchOptions",
-        "record-schema-metadata-alembic": "test",
-        "invenio-record-resource-extra-code": "",
-        "proxies-current-service": "test.proxies.current_service",
-        "invenio-record-metadata-extra-code": "",
-        "record-metadata-class": "test.records.models.TestMetadata",
-        "invenio-version-extra-code": "",
-        "schema-server": "http://localhost/schemas/",
-        "package-base": "test",
-        "record-blueprints-setup-cfg": "test",
-        "jsonschemas-package": "test.records.jsonschemas",
-        "record-metadata-table-name": "test_metadata",
-        "model-name": "test",
-        "config-resource-config-key": "TEST_RESOURCE_CONFIG_TEST",
-        "record-jsonschemas-setup-cfg": "test",
-        "invenio-record-object-schema-extra-code": "",
-        "oarepo-models-setup-cfg": "test",
-        "config-package": "test.config",
-        "invenio-record-dumper-extra-code": "",
-        "ui": {
-            "marshmallow": {
-                "schema-class": "test.services.records.ui_schema.TestUISchema",  # NOSONAR
-                "generate": True,
-                "base-classes": ["BaseObjectSchema"],
-            }
-        },
-        "record-services-package": "test.services.records",
-        "generate-record-pid-field": True,
-        "invenio-record-search-options-extra-code": "",
-        "record-facets-class": "test.services.records.facets.Test",
         "proxies-current-resource": "test.proxies.current_resource",
-        "invenio-views-extra-code": "",
-        "config-service-class-key": "TEST_SERVICE_CLASS_TEST",
-        "mapping-file": "test/records/mappings/os-v2/test/test-1.0.0.json",
-        "package": "test",
-        "record-schema-metadata-class": "test.services.records.schema.TestMetadataSchema",
-        "invenio-config-extra-code": "",
-        "record-service-config-generate-links": True,
-        "schema-file": "test/records/jsonschemas/test-1.0.0.json",
-        "config-service-config-key": "TEST_SERVICE_CONFIG_TEST",
-        "config-resource-class-key": "TEST_RESOURCE_CLASS_TEST",
+        "proxies-current-service": "test.proxies.current_service",
+        "record-api-blueprints-setup-cfg": "test",
+        "record-blueprints-setup-cfg": "test",
         "record-class": "test.records.api.TestRecord",
-        "record-permissions-class": "test.services.records.permissions.TestPermissionPolicy",
-        "record-resources-package": "test.resources.records",
-        "record-service-config-class": "test.services.records.config.TestServiceConfig",
-        "record-schema-class": "test.services.records.schema.TestSchema",
-        "invenio-record-resource-config-extra-code": "",
         "record-dumper-class": "test.records.dumper.TestDumper",
-        "extension-suffix": "test",
-        "package-path": "test",
-        "permissions": {"presets": []},
-        "index-name": "test-test-1.0.0",
-        "service-id": "test",
-        "config-dummy-class": "test.config.DummyClass",
+        "record-dumper-extensions": [],
+        "record-facets-class": "test.services.records.facets.Test",
+        "record-jsonschemas-setup-cfg": "test",
+        "record-mapping-setup-cfg": "test",
+        "record-metadata-class": "test.records.models.TestMetadata",
+        "record-metadata-table-name": "test_metadata",
+        "record-permissions-class": "test.services.records.permissions.TestPermissionPolicy",
+        "record-prefix": "Test",
+        "record-prefix-snake": "test",
+        "record-records-package": "test.records",
+        "record-resource-blueprint-name": "Test",
+        "record-resource-class": "test.resources.records.resource.TestResource",
+        "record-resource-config-class": "test.resources.records.config.TestResourceConfig",
+        "record-resources-package": "test.resources.records",
+        "record-schema-class": "test.services.records.schema.TestSchema",
+        "record-schema-metadata-alembic": "test",
+        "record-schema-metadata-class": "test.services.records.schema.TestMetadataSchema",
+        "record-schema-metadata-setup-cfg": "test",
+        "record-search-options-class": "test.services.records.search.TestSearchOptions",
+        "record-service-class": "test.services.records.service.TestService",
+        "record-service-config-class": "test.services.records.config.TestServiceConfig",
+        "record-service-config-generate-links": True,
+        "record-services-package": "test.services.records",
+        "record-ui-schema-class": "test.services.records.ui_schema.TestUISchema",
+        "record-ui-schema-metadata-class": "test.services.records.ui_schema.TestMetadataUISchema",
+        "record-ui-serializer-class": "test.resources.records.ui.TestUIJSONSerializer",
+        "saved-model-file": "test/models/model.json",
+        "schema-file": "test/records/jsonschemas/test-1.0.0.json",
+        "schema-name": "test-1.0.0.json",
+        "schema-server": "http://localhost/schemas/",
         "schema-version": "1.0.0",
         "script-import-sample-data": "data/sample_data.yaml",
-        "saved-model-file": "test/models/model.json",
-        "invenio-record-service-extra-code": "",
-        "profile-package": "records",
-        "invenio-proxies-extra-code": "",
-        "record-resource-blueprint-name": "Test",
-        "mapping-package": "test.records.mappings",
-        "record-schema-metadata-setup-cfg": "test",
-        "record-resource-class": "test.resources.records.resource.TestResource",
-        "record-prefix-snake": "test",
-        "cli-function": "test.cli.group",
-        "record-mapping-setup-cfg": "test",
-        "record-ui-serializer-class": "test.resources.records.ui.TestUIJSONSerializer",
+        "service-id": "test",
+        "type": "object",
+        "ui": {
+            "marshmallow": {
+                "base-classes": ["BaseObjectSchema"],
+                "generate": True,
+                "schema-class": "test.services.records.ui_schema.TestUISchema",
+            }
+        },
     }
     assert data[1].strip() == ""
     assert (
@@ -275,6 +283,7 @@ def test_model_saver_invenio():
         "record-search-options-class": "test.services.records.search.TestSearchOptions",
         "invenio-version-extra-code": "",
         "record-ui-schema-class": "test.services.records.ui_schema.TestUISchema",  # NOSOONAR
+        "record-ui-schema-metadata-class": "test.services.records.ui_schema.TestMetadataUISchema",  # NOSONAR
         "index-name": "test-test-1.0.0",
         "schema-server": "http://localhost/schemas/",
         "service-id": "test",
